'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');

/**
 * React Typescript Rotating Canvas Circles
 *
 */
var Circles = function (_a) {
    var numCircles = _a.numCircles, speed = _a.speed;
    var canvasRef = React.useRef(null);
    var cx;
    var cy;
    var radius;
    var angleSpeed;
    var totalCircles = numCircles;
    /**
     * Responsive dimensions based on parent element
     *
     * Operates on the HTMLCanvasElement api
     */
    var setDimensions = function () {
        if (!canvasRef.current) {
            return;
        }
        var canvas = canvasRef.current;
        var parent = canvas.parentElement;
        if (!parent) {
            return;
        }
        var styles = getComputedStyle(parent);
        var w = parseInt(styles.getPropertyValue('width'), 10);
        var h = parseInt(styles.getPropertyValue('height'), 10);
        var maxW = window.innerWidth;
        var maxH = window.innerHeight;
        canvas.width = Math.min(w, maxW);
        canvas.height = Math.min(h, maxH);
        cx = canvas.width / 2;
        cy = canvas.height / 2;
        radius = 0;
        angleSpeed = 0;
    };
    /**
     * RGB Color fade algorithm
     *
     * Operates on the CanvasRenderingContext2D strokeStyle api
     */
    var rgbAlgorithm = function () {
        if (!canvasRef.current) {
            return;
        }
        var canvas = canvasRef.current;
        var ctx = canvas.getContext('2d');
        var r = 255;
        var g = 0;
        var b = 0;
        if (ctx) {
            setInterval(function () {
                if (r > 0 && b === 0) {
                    r--;
                    g++;
                }
                if (g > 0 && r === 0) {
                    g--;
                    b++;
                }
                if (b > 0 && g === 0) {
                    r++;
                    b--;
                }
                var color = "rgb(" + r + "," + g + "," + b + ")";
                // Change the canvas circle color
                ctx.strokeStyle = color;
            }, 50);
        }
    };
    /**
     * Circle Rendering function
     *
     * Operates on the CanvasRenderingContext2D api
     */
    var draw = function () {
        if (!canvasRef.current) {
            return;
        }
        var canvas = canvasRef.current;
        var ctx = canvas.getContext('2d');
        if (ctx) {
            ctx.clearRect(0, 0, canvas.width, canvas.height);
            for (var i = 0; i < totalCircles; i++) {
                var angle = (i * angleSpeed * Math.PI) / totalCircles;
                var x = cx + Math.cos(angle) * radius;
                var y = cy + Math.sin(angle) * radius;
                ctx.beginPath();
                ctx.arc(x, y, radius, 0, Math.PI * 2, true);
                ctx.closePath();
                ctx.stroke();
            }
            var minSide = Math.min(canvas.height, canvas.width);
            // Control the circle growth
            while (radius < minSide / 4) {
                radius = minSide / 4;
                angleSpeed += 10;
            }
            angleSpeed += speed === 'fast' ? 0.005 : 0.0005;
        }
    };
    React.useEffect(function () {
        rgbAlgorithm();
        setDimensions();
        setInterval(draw, 15);
    });
    window.addEventListener('load', rgbAlgorithm);
    window.addEventListener('load', setDimensions);
    window.addEventListener('resize', setDimensions);
    return React.createElement("canvas", { id: "react-circles", ref: canvasRef });
};

exports.default = Circles;
//# sourceMappingURL=index.js.map
